@@ -5,9 +5,12 @@ use strict;
 sub config { {
 	version => 1,  # oauth 1.0a
 	request_token_url => 'https://api.twitter.com/oauth/request_token',
+	request_token_method => 'POST',
+
 	access_token_url  => 'https://api.twitter.com/oauth/access_token',
+	access_token_method => 'POST',
+
 	authorize_url     => 'https://api.twitter.com/oauth/authenticate',
-	request_method   => 'POST',
 } }
 
 1;
